import { AssetManager } from "./asset-manager.js";
import type { ContentAsset, ContentAssetMetadataMap, ContentAssetMetadataMapEntry, ContentAssetMetadataMapEntryBytes, ContentAssetMetadataMapEntryString } from "../../types/content-assets.js";
import type { StoreEntry } from "../../types/compute.js";
import type { ContentCompressionTypes } from "../../constants/compression.js";
export type SourceAndInfo<TSource> = {
    source: TSource;
    hash: string;
    size: number;
};
type SourceAndInfoForEncodingFn<TSource> = (contentEncoding: ContentCompressionTypes) => SourceAndInfo<TSource> | undefined;
export declare function findMatchingSourceAndInfo<TSource>(acceptEncodingsGroups: ContentCompressionTypes[][], defaultSourceAndInfo: SourceAndInfo<TSource>, sourceAndInfoForEncodingFn: SourceAndInfoForEncodingFn<TSource>): {
    sourceAndInfo: SourceAndInfo<TSource>;
    contentEncoding: "br" | "gzip" | null;
};
declare abstract class ContentRuntimeAsset<TMetadataMapEntry extends ContentAssetMetadataMapEntry> {
    protected readonly metadata: TMetadataMapEntry;
    protected sourceAndInfo: SourceAndInfo<Uint8Array>;
    protected constructor(metadata: TMetadataMapEntry, sourceAndInfo: SourceAndInfo<Uint8Array>);
    get isLocal(): boolean;
    get assetKey(): string;
    getStoreEntry(): Promise<StoreEntry>;
    getBytes(): Uint8Array;
    getText(): string;
    getMetadata(): ContentAssetMetadataMapEntry;
}
export declare class ContentBytesAsset extends ContentRuntimeAsset<ContentAssetMetadataMapEntryBytes> implements ContentAsset {
    readonly type = "bytes";
    constructor(metadata: ContentAssetMetadataMapEntryBytes);
}
export declare class ContentStringAsset extends ContentRuntimeAsset<ContentAssetMetadataMapEntryString> implements ContentAsset {
    readonly type = "string";
    static encoder: TextEncoder;
    constructor(metadata: ContentAssetMetadataMapEntryString);
}
export type AssetBuilder<TType extends string> = (metadata: ContentAssetMetadataMapEntry & {
    type: TType;
}, assetBuilderContext: AssetBuilderContext) => ContentAsset;
type AssetBuilderContext = any;
export declare class ContentAssets extends AssetManager<ContentAsset> {
    static builders: Record<string, AssetBuilder<any>>;
    constructor(contentAssetMetadataMap: ContentAssetMetadataMap, assetBuilderContext?: AssetBuilderContext);
    static registerAssetBuilder<TType extends string>(type: TType, builder: AssetBuilder<TType>): void;
}
export {};
//# sourceMappingURL=content-assets.d.ts.map